AxisLabelCreatedArgs class

Returns the AxisLabelCreatedArgs used by the RadialAxis.onLabelCreated event.

Constructors

AxisLabelCreatedArgs()

Properties

canRotate ↔ bool?
whether to rotate the label based on angle.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labelStyle ↔ GaugeTextStyle?
Specifies the label style
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
Holds the label text
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited