AxisLineStyle class

Create the style of axis line.

Widget build(BuildContext context) {
   return Container(
       child: SfRadialGauge(
         axes:<RadialAxis>[RadialAxis(
          axisLineStyle: AxisLineStyle(color: Colors.red,
          thickness: 20),
           )]
       ));
}
Annotations

Constructors

AxisLineStyle({double thickness = 10, GaugeSizeUnit thicknessUnit = GaugeSizeUnit.logicalPixel, Color? color, Gradient? gradient, CornerStyle cornerStyle = CornerStyle.bothFlat, List<double>? dashArray})
Creates a minor tick style with default or required properties.
const

Properties

color → Color?
Specifies the color of axis line.
final
cornerStyle → CornerStyle
The style to use for the axis line corner edge.
final
dashArray → List<double>?
Specifies the dash array for axis line to draw the dashed line.
final
gradient → Gradient?
A gradient to use when filling the axis line.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double
Specifies the thickness of axis line.
final
thicknessUnit → GaugeSizeUnit
Calculates the axis line thickness either in logical pixel or radius factor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override