CircularAxisLabel class

Holds the axis label information.

Constructors

CircularAxisLabel(GaugeTextStyle labelStyle, String text, num index, bool needsRotateLabel)
Creates the axis label with default or required properties.

Properties

angle ↔ double
Holds the corresponding angle for the label
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ num
Specifies the axis index position
getter/setter pair
labelSize ↔ Size
Holds the size of axis label
getter/setter pair
labelStyle ↔ GaugeTextStyle
Style for axis label text.
getter/setter pair
needsRotateLabel → bool
Specifies whether to rotate the corresponding labels
final
position ↔ Offset
Holds the label position
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
Text to display
getter/setter pair
value ↔ num
Specifies the value of the labels
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited