GaugePointer class abstract

GaugePointer has properties for customizing gauge pointers.

Implementers

Constructors

GaugePointer({double value = 0, bool enableDragging = false, ValueChanged<double>? onValueChanged, ValueChanged<double>? onValueChangeStart, ValueChanged<ValueChangingArgs>? onValueChanging, ValueChanged<double>? onValueChangeEnd, bool enableAnimation = false, AnimationType animationType = AnimationType.ease, double animationDuration = 1000})
Create a pointer with the default or required properties.

Properties

animationDuration → double
Specifies the duration of the pointer animation.
final
animationType → AnimationType
Specifies the different type of animation for pointer.
final
enableAnimation → bool
Whether to enable the pointer animation.
final
enableDragging → bool
Whether to allow the pointer dragging.
final
hashCode → int
The hash code for this object.
no setterinherited
onValueChanged → ValueChanged<double>?
Called during a drag when the user is selecting a new value for the pointer by dragging.
final
onValueChangeEnd → ValueChanged<double>?
Called when the user is done selecting a new value of the pointer by dragging.
final
onValueChangeStart → ValueChanged<double>?
Called when the user starts selecting a new value of pointer by dragging.
final
onValueChanging → ValueChanged<ValueChangingArgs>?
Called during a drag when the user is selecting before a new value for the pointer by dragging.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
Specifies the value to the pointer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited