GaugeTextStyle class

This class has the property of the guage text style.

Provides the options of color, font family, font style, font size, and font-weight to customize the appearance.

Annotations

Constructors

GaugeTextStyle({Color? color, String? fontFamily, FontStyle? fontStyle, FontWeight? fontWeight, double? fontSize})
Creates a gauge text style with default or required properties.
const

Properties

color → Color?
To set the color of guage text.
final
fontFamily → String?
To set the font family to guage text.
final
fontSize → double?
To set the font size to gauge text
final
fontStyle → FontStyle?
To set the font style to guage text.
final
fontWeight → FontWeight?
To set the font weight to gauge text.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override