KnobStyle class

A style in which draw needle pointer knob.

Widget build(BuildContext context) {
   return Container(
       child: SfRadialGauge(
         axes:<RadialAxis>[RadialAxis
         ( pointers: <GaugePointer>[
            NeedlePointer( value: 30,
             knobStyle: KnobStyle(knobRadius: 0.1),
          )])]
       ));
}
Annotations

Constructors

KnobStyle({double knobRadius = 0.08, double borderWidth = 0, GaugeSizeUnit sizeUnit = GaugeSizeUnit.factor, Color? borderColor, Color? color})
Creates the knob style with default or required properties.
const

Properties

borderColor → Color?
Specifies the knob border color.
final
borderWidth → double
Specifies the knob border width in logical pixel.
final
color → Color?
Specifies the knob color.
final
hashCode → int
The hash code for this object.
no setteroverride
knobRadius → double
Adjusts the knob radius in needle pointer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeUnit → GaugeSizeUnit
Calculates the knob radius size either in logical pixel or radius factor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override