LinearAxisTrackStyle class

LinearAxisTrackStyle has properties for customizing the axis track.

Annotations

Constructors

LinearAxisTrackStyle({double thickness = 5.0, LinearEdgeStyle edgeStyle = LinearEdgeStyle.bothFlat, Color? color, LinearGradient? gradient, Color? borderColor, double borderWidth = 0})
Creates a style for axis line.
const

Properties

borderColor → Color?
Specifies the border color for an axis track.
final
borderWidth → double
Specifies the border width of an axis track.
final
color → Color?
Specifies the color to be applied for an axis track.
final
edgeStyle → LinearEdgeStyle
Specifies the edge styles for an axis track.
final
gradient → LinearGradient?
Specifies the gradient colors for an axis track.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double
Specifies the thickness value of an axis track.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override