LinearMarkerPointer class abstract

LinearMarkerPointer has properties for customizing linear gauge pointers.

Implementers

Constructors

LinearMarkerPointer({required double value, ValueChanged<double>? onChanged, ValueChanged<double>? onChangeStart, ValueChanged<double>? onChangeEnd, bool enableAnimation = false, int animationDuration = 1000, LinearAnimationType animationType = LinearAnimationType.ease, double offset = 0.0, LinearMarkerAlignment markerAlignment = LinearMarkerAlignment.center, LinearElementPosition position = LinearElementPosition.cross, LinearMarkerDragBehavior dragBehavior = LinearMarkerDragBehavior.free, VoidCallback? onAnimationCompleted})
Creates a pointer for linear axis with the default or required properties.

Properties

animationDuration → int
Specifies the animation duration for the pointer. Duration is defined in milliseconds.
final
animationType → LinearAnimationType
Specifies the type of the animation for the pointer.
final
dragBehavior → LinearMarkerDragBehavior
Specifies the drag behavior for the pointer.
final
enableAnimation → bool
Specifies whether to enable animation or not, when the pointer moves.
final
hashCode → int
The hash code for this object.
no setterinherited
markerAlignment → LinearMarkerAlignment
Specifies the marker alignment.
final
offset → double
Specifies the offset value which represent the gap from the linear axis. Origin of this property will be relates to LinearMarkerPointer.position.
final
onAnimationCompleted → VoidCallback?
Specifies the animation completed callback.
final
onChanged → ValueChanged<double>?
Signature for a callback that report that a value was changed for a marker pointer.
final
onChangeEnd → ValueChanged<double>?
Signature for a callback that reports the value changes are ended for a marker pointer.
final
onChangeStart → ValueChanged<double>?
Signature for a callback that reports the value of a marker pointer has started to change.
final
position → LinearElementPosition
Specifies the annotation position with respect to linear axis.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
Specifies the linear axis value to place the pointer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited