MarkerPointerRenderer class

The MarkerPointerRenderer has methods to render marker pointer

Constructors

MarkerPointerRenderer()
Creates the instance for marker pointer renderer

Properties

hashCode → int
The hash code for this object.
no setterinherited
pointer ↔ MarkerPointer
Represents the marker pointer which is corresponding to this renderer
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

drawPointer(Canvas canvas, PointerPaintingDetails pointerPaintingDetails, SfGaugeThemeData gaugeThemeData) → void
Method to draw pointer the marker pointer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited