RadialAxis class

The RadialAxis is a circular arc in which a set of values are displayed along a linear or custom scale based on the design requirements.

Widget build(BuildContext context) {
   return Container(
       child: SfRadialGauge(
         axes:<RadialAxis>[RadialAxis(
           )]
       ));
}
Inheritance

Constructors

RadialAxis({Key? key, double startAngle = 130, double endAngle = 50, double radiusFactor = 0.95, double centerX = 0.5, double centerY = 0.5, ValueChanged<AxisLabelCreatedArgs>? onLabelCreated, ValueChanged<double>? onAxisTapped, bool canRotateLabels = false, bool showFirstLabel = true, bool showLastLabel = false, bool canScaleToFit = false, ImageProvider<Object>? backgroundImage, List<GaugeRange>? ranges, List<GaugePointer>? pointers, List<GaugeAnnotation>? annotations, double minimum = 0, double maximum = 100, double? interval, double minorTicksPerInterval = 1, bool showLabels = true, bool showAxisLine = true, bool showTicks = true, double tickOffset = 0, double labelOffset = 15, bool isInversed = false, int maximumLabels = 3, bool useRangeColorForAxis = false, String? labelFormat, NumberFormat? numberFormat, GaugeAxisRendererFactory? onCreateAxisRenderer, ElementsPosition ticksPosition = ElementsPosition.inside, ElementsPosition labelsPosition = ElementsPosition.inside, GaugeSizeUnit offsetUnit = GaugeSizeUnit.logicalPixel, GaugeTextStyle? axisLabelStyle, AxisLineStyle? axisLineStyle, MajorTickStyle? majorTickStyle, MinorTickStyle? minorTickStyle})
Create RadialAxis with the default or required scale range and customized axis properties.

Properties

annotations → List<GaugeAnnotation>?
Add a list of gauge annotation to the radial gauge and customize each annotation by adding it to the annotations collection.
final
axisLabelStyle → GaugeTextStyle
The style to use for the axis label text.
final
axisLineStyle → AxisLineStyle
The style to use for the axis line.
final
backgroundImage → ImageProvider<Object>?
The background image of the RadialAxis. Changing the image will set the background to the new image.
final
canRotateLabels → bool
whether to rotate the labels based on angle.
final
canScaleToFit → bool
Adjust the half or quarter gauge to fit the axis boundary.
final
centerX → double
Left location of center axis.
final
centerY → double
Top location of center axis.
final
endAngle → double
Specifies the end angle of axis.
final
hashCode → int
The hash code for this object.
no setterinherited
interval → double?
The interval value for the axis.
final
isInversed → bool
Inverts the axis from right to left.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelFormat → String?
Formats the axis labels.
final
labelOffset → double
Adjusts the axis label distance from tick end.
final
labelsPosition → ElementsPosition
Positions the axis labels inside or outside the axis line.
final
majorTickStyle → MajorTickStyle
The style to use for the major axis tick lines.
final
maximum → double
The maximum value for the axis.
final
maximumLabels → int
The maximum number of labels to be displayed in 100 logical pixels on the axis.
final
minimum → double
The minimum value for the axis.
final
minorTicksPerInterval → double
Add minor ticks count per interval.
final
minorTickStyle → MinorTickStyle
The style to use for the minor axis tick lines.
final
numberFormat → NumberFormat?
Formats the axis labels with globalized label formats.
final
offsetUnit → GaugeSizeUnit
Calculates the position either in logical pixel or radius factor.
final
onAxisTapped → ValueChanged<double>?
Callback, which is triggered by tapping an axis.
final
onCreateAxisRenderer → GaugeAxisRendererFactory?
The callback that is called when the custom renderer for the custom axis is created. and it is not applicable for built-in axis
final
onLabelCreated → ValueChanged<AxisLabelCreatedArgs>?
Callback that gets triggered when an axis label is created.
final
pointers → List<GaugePointer>?
Add a list of gauge pointer to the radial gauge and customize each pointer by adding it to the pointers collection.
final
radiusFactor → double
The size of the axis, expressed as the radius (half the diameter) in factor.
final
ranges → List<GaugeRange>?
Add a list of gauge range to the radial gauge and customize each range by adding it to the ranges collection.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAxisLine → bool
Whether to show the axis line of the gauge.
final
showFirstLabel → bool
Whether to show the first label of the axis.
final
showLabels → bool
Whether to show the labels on the axis of the gauge.
final
showLastLabel → bool
Whether to show the last label of the axis.
final
showTicks → bool
Whether to show the ticks on the axis of the gauge.
final
startAngle → double
Specifies the start angle of axis.
final
tickOffset → double
Adjusts the axis ticks distance from the axis line.
final
ticksPosition → ElementsPosition
Positions the tick lines inside or outside the axis line.
final
useRangeColorForAxis → bool
Whether to use the range color for axis elements such as labels and ticks.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited