RadialAxisRenderer class

Represents the renderer for radial axis

Inheritance

Constructors

RadialAxisRenderer()
Creates the instance for radial axis renderer

Properties

axis ↔ RadialAxis
Represents the gauge axis
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

factorToValue(double factor) → double?
Returns converted axis value from the factor.
override
generateVisibleLabels() → List<CircularAxisLabel>?
Returns the visible labels on RadialAxis
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueToFactor(double value) → double?
Returns converted factor value from the axis value.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited