TailStyle class

Style for drawing pointer's tail.

Widget build(BuildContext context) {
   return Container(
       child: SfRadialGauge(
         axes:<RadialAxis>[RadialAxis
         ( pointers: <GaugePointer>[
            NeedlePointer( value: 20, tailStyle:
                TailStyle(width: 5, lengthFactor: 0.2)
          )])]
       ));
}
Annotations

Constructors

TailStyle({Color? color, double width = 0, double length = 0, double borderWidth = 0, LinearGradient? gradient, GaugeSizeUnit lengthUnit = GaugeSizeUnit.factor, Color? borderColor})
Creates the tail style with default or required properties.
const

Properties

borderColor → Color?
Specifies the border color of tail.
final
borderWidth → double
Specifies the border width of tail.
final
color → Color?
Specifies the color of the tail.
final
gradient → LinearGradient?
A gradient to use when filling the needle tail.
final
hashCode → int
The hash code for this object.
no setteroverride
length → double
Adjusts the tail length from center.
final
lengthUnit → GaugeSizeUnit
Calculates the pointer tail length either in logical pixel or radius factor.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
Specifies the width of the tail.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override